package com.caimei365.manager.controller.caimei.finance;

import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.ReceiptPermission;
import com.caimei365.manager.entity.caimei.ReceiptUser;
import com.caimei365.manager.service.caimei.ReceiptUserService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 线下收款用户接口
 * @author Charles
 */
@RestController
@RequestMapping("/finance")
public class ReceiptUserApi {


    @Resource
    private ReceiptUserService receiptUserService;

    /**
     * 获取收款用户列表
     */
    @GetMapping("/receipt/users")
    public ResponseJson<List<ReceiptUser>> getReceiptUsers() {
        return receiptUserService.getReceiptUsers();
    }

    /**
     * 获取收款权限列表
     */
    @GetMapping("/receipt/permissions")
    public ResponseJson<List<ReceiptPermission>> getReceiptPermissions() {
        return receiptUserService.getReceiptPermissions();
    }


    /**
     * 根据ID获取收款用户
     */
    @GetMapping("/receipt/user/{id}")
    public ResponseJson<ReceiptUser> getReceiptUser(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("收款用户Id不能为空！", null);
        }
        return receiptUserService.getReceiptUser(id);
    }

    /**
     * 添加收款用户
     */
    @PostMapping("/receipt/user/create")
    public ResponseJson<Void> addReceiptUser(@RequestBody ReceiptUser receiptUser) {
        return receiptUserService.addReceiptUser(receiptUser);
    }

    /**
     * 根据ID更新用户
     */
    @PostMapping("/receipt/user/update/{id}")
    public ResponseJson<Void> updateReceiptUser(@PathVariable("id") Integer id, @RequestBody ReceiptUser receiptUser) {
        if (null == id || id <= 0) {
            return ResponseJson.error("收款用户Id不能为空！", null);
        }
        return receiptUserService.updateReceiptUser(id, receiptUser);
    }

    /**
     * 根据ID删除收款用户
     */
    @PostMapping("/receipt/user/delete/{id}")
    public ResponseJson<Void> deleteReceiptUser(@PathVariable("id") Integer id) {
        if (null == id || id <= 0) {
            return ResponseJson.error("收款用户Id不能为空！", null);
        }
        return receiptUserService.deleteReceiptUser(id);
    }

}
