package com.caimei365.manager.controller.caimei.svip;

import com.caimei.utils.StringUtils;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.CmUser;
import com.caimei365.manager.entity.caimei.product.Product;
import com.caimei365.manager.entity.caimei.svip.*;
import com.caimei365.manager.service.caimei.svip.CmSvipHistoryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/4/7
 */
@RestController
@RequestMapping("/svip/member")
public class CmSvipHistoryApi {

    @Autowired private CmSvipHistoryService historyService;

    /**
     * 超级会员列表
     * @param vip
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/memberList")
    public ResponseJson<PaginationVo<CmSvipHistory>> memberList(CmSvipHistory vip,
                                                 @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                 @RequestParam(value = "pageSize",defaultValue = "20")int pageSize) {

        return historyService.memberList(vip, pageNum, pageSize);
    }

    /**
     * 获取机构信息
     * @param clubId
     * @param name
     * @param shortName
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/findClubList")
    public ResponseJson<PaginationVo<CmUser>> findClubList(Integer clubId, String name, String shortName,
                                                            @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                            @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {

        return historyService.findClubList(clubId, name, shortName, pageNum, pageSize);
    }

    /**
     * 赠送超级会员
     * @param cmSvipGive
     * @return
     * @throws Exception
     */
    @PostMapping("/saveSvip")
    public ResponseJson save(CmSvipGive cmSvipGive) throws Exception {
        if (StringUtils.isBlank(cmSvipGive.getUserId()) || null == cmSvipGive.getMonth() || null == cmSvipGive.getClubId()) {
            return ResponseJson.error("参数错误或缺少参数", null);
        }
        return historyService.saveGive(cmSvipGive);
    }

    /**
     * 机构购买记录
     * @param cmSvipHistory
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/findHistory")
    public ResponseJson<PaginationVo<CmSvipHistory>> findHistory(CmSvipHistory cmSvipHistory,
                                                                 @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                 @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        if (null == cmSvipHistory.getUserId()) {
            return ResponseJson.error(-1,"",null);
        }
        return historyService.findHistory(cmSvipHistory, pageNum, pageSize);
    }

    /**
     * 超级会员专属优惠券
     * @param cmVipCoupon
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/couponList")
    public ResponseJson<PaginationVo<CmVipCoupon>> couponList(CmVipCoupon cmVipCoupon,
                                                              @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                              @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return historyService.couponList(cmVipCoupon, pageNum, pageSize);
    }

    /**
     * 关闭超级会员专属优惠券
     * @param id
     * @return
     */
    @GetMapping("/closeCoupon")
    public ResponseJson closeCoupon(Integer id) {
        if (null == id) {
            return ResponseJson.error(-1,"参数为空", null);
        }
        return historyService.closeCoupon(id);
    }

    /**
     * 开启超级会员专属优惠券
     * @param id
     * @return
     */
    @GetMapping("/openCoupon")
    public ResponseJson openCoupon(Integer id) {
        if (null == id) {
            return ResponseJson.error(-1,"参数为空", null);
        }
        return historyService.openCoupon(id);
    }

    /**
     * 删除超级会员专属优惠券
     * @param id
     * @return
     */
    @GetMapping("/deleteCoupon")
    public ResponseJson deleteCoupon(Integer id) {
        if (null == id) {
            return ResponseJson.error(-1,"参数为空", null);
        }
        return historyService.deleteCoupon(id);
    }

    /**
     * 获取供应商列表
     * @param cmShop
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/findShopList")
    public ResponseJson<PaginationVo<NewCmShop>> findShopList(NewCmShop cmShop,
                                                              @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                              @RequestParam(value = "pageSize",defaultValue = "20")int pageSize) {

        return historyService.findShopList(cmShop, pageNum, pageSize);
    }

    /**
     * 获取商品信息列表
     * @param product
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/findProductDialogList")
    public ResponseJson<PaginationVo<Product>> findProductList(Product product,
                                                               @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                               @RequestParam(value = "pageSize",defaultValue = "20") int pageSize) {
        return historyService.findProductDialogList(product, pageNum, pageSize);
    }

    /**
     * 超级会员商品列表
     * @param cmSvipProduct
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/findProductList")
    public ResponseJson<PaginationVo<CmSvipProduct>> findProductList (CmSvipProduct cmSvipProduct,
                                                                      @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                      @RequestParam(value = "pageSize",defaultValue = "20")int pageSize) {

        return historyService.findProductList(cmSvipProduct, pageNum, pageSize);
    }

    /**
     * 套餐配置
     * @return
     */
    @GetMapping("/findPackage")
    public ResponseJson<CmSvipPackage> findPackage() {
        return historyService.findPackage();
    }

    /**
     * 更新超级会员套餐配置
     * @param cmSvipPackage
     * @return
     */
    @PostMapping("/updatePrice")
    public ResponseJson updatePrice(CmSvipPackage cmSvipPackage) {
        return historyService.updatePrice(cmSvipPackage);
    }
}
