package com.caimei365.manager.service.wechat.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.caimei365.manager.dao.SystemDao;
import com.caimei365.manager.dao.WeChatDao;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.wechat.WechatMenu;
import com.caimei365.manager.service.wechat.WechatMenuService;
import com.caimei365.manager.utils.HttpUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/1/5
 */
@Slf4j
@Service
public class WechatMenuServiceImpl implements WechatMenuService {

    @Value("${wechat.apiUrl}")
    private String wechatApiUrl;
    @Value("${wechat.publicUrl}")
    private String publicUrl;

    @Value("${wechat.caimei.id}")
    private String caimeiId;
    @Value("${wechat.caimei.appid}")
    private String caimeiAppid;
    @Value("${wechat.caimei.secret}")
    private String caimeiSecret;

    @Value("${wechat.hehe.id}")
    private String heheId;
    @Value("${wechat.hehe.appid}")
    private String heheAppid;
    @Value("${wechat.hehe.secret}")
    private String heheSecret;

    @Resource
    private WeChatDao weChatDao;
    @Resource
    private SystemDao systemDao;

    /**
     * 获取微信公众号菜单列表
     *
     * @param type 类型： 1采美，2呵呵商城
     */
    @Override
    public ResponseJson<List<WechatMenu>> getWechatMenuList(Integer type) {
        String wxType = "";
        if (null != type && 1 == type) {
            wxType = caimeiId;
        } else if (null != type && 2 == type) {
            wxType = heheId;
        } else {
            return ResponseJson.error("菜单类型不能为空", null);
        }
        // 获取根菜单
        WechatMenu rootMenu = weChatDao.getWechatMenu(type);
        // 获取一级菜单列表
        List<WechatMenu> list = weChatDao.getWechatMenuList(type, wxType);
        // 获取子菜单
        for (WechatMenu menu : list) {
            List<WechatMenu> subList = weChatDao.getWechatMenuList(menu.getId(), wxType);
            for (WechatMenu sub : subList) {
                sub.setParentName(menu.getName());
            }
            menu.setParentName(rootMenu.getName());
            menu.setChildren(subList);
        }
        return ResponseJson.success(list);
    }

    /**
     * 根据ID获取微信公众号菜单
     *
     * @param id 菜单Id
     */
    @Override
    public ResponseJson<WechatMenu> getWechatMenu(Integer id) {
        WechatMenu menu = weChatDao.getWechatMenu(id);
        return ResponseJson.success(menu);
    }

    /**
     * 根据ID更新微信公众号菜单
     *
     * @param id   菜单Id
     */
    @Override
    public ResponseJson<Void> updateWechatMenu(Integer id, WechatMenu menu, String username) {
        WechatMenu dbMenu = weChatDao.getWechatMenu(id);
        if (null == dbMenu) {
            return ResponseJson.error("当前菜单异常！", null);
        }
        if (StringUtils.hasLength(menu.getName())){
            dbMenu.setName(menu.getName());
        }
        if (StringUtils.hasLength(menu.getType())){
            dbMenu.setType(menu.getType());
        }
        if (StringUtils.hasLength(menu.getKey())){
            dbMenu.setKey(menu.getKey());
        }
        if (StringUtils.hasLength(menu.getUrl())){
            dbMenu.setUrl(menu.getUrl());
        }
        if (StringUtils.hasLength(menu.getMediaId())){
            dbMenu.setMediaId(menu.getMediaId());
        }
        if (StringUtils.hasLength(menu.getAppid())){
            dbMenu.setAppid(menu.getAppid());
        }
        if (StringUtils.hasLength(menu.getPagePath())){
            dbMenu.setPagePath(menu.getPagePath());
        }
        if (null != menu.getSort()){
            dbMenu.setSort(menu.getSort());
        }
        WechatMenu parentMenu = weChatDao.getWechatMenu(dbMenu.getParentId());
        setParentIds(dbMenu, parentMenu, username);
        // 更新
        weChatDao.updateWechatMenu(dbMenu);
        return ResponseJson.success();
    }

    /**
     * 添加微信公众号菜单
     */
    @Override
    public ResponseJson<Void> addWechatMenu(WechatMenu menu, String username) {
        if (!StringUtils.hasLength(menu.getName())) {
            return ResponseJson.error("菜单标题不能为空！", null);
        }
        if (null == menu.getParentId()) {
            return ResponseJson.error("父级菜单Id不能为空！", null);
        }
        WechatMenu parentMenu = weChatDao.getWechatMenu(menu.getParentId());
        if (null == parentMenu) {
            return ResponseJson.error("父级菜单异常！", null);
        }
        menu.setWxType(parentMenu.getWxType());
        // 根据父级Id统计同级别菜单数量
        Integer count = weChatDao.countChildByParentId(menu.getParentId());
        // 一级菜单
        if (menu.getParentId() == 1 || menu.getParentId() == 2) {
            if (count >= 3) {
                return ResponseJson.error("最多包括3个一级菜单！", null);
            }
        } else {
            if (count >= 5) {
                return ResponseJson.error("每个一级菜单最多包含5个二级菜单！", null);
            }
        }
        setParentIds(menu, parentMenu, username);
        // 新增
        weChatDao.insertWechatMenu(menu);
        return ResponseJson.success();
    }

    /**
     * 设置操作人与父级ID串
     * @param menu     待更新菜单
     * @param username 操作人登录名
     */
    private void setParentIds(WechatMenu menu, WechatMenu parentMenu, String username) {
        Integer userId = systemDao.getUserIdByUsername(username);
        menu.setUserId(userId);
        String parentIds = "0,";
        if (null != parentMenu && StringUtils.hasLength(parentMenu.getParentIds())) {
            parentIds = parentMenu.getParentIds() + parentMenu.getId() + ",";
        }
        menu.setParentIds(parentIds);
    }

    /**
     * 根据ID删除微信公众号菜单
     *
     * @param id 菜单Id
     */
    @Override
    public ResponseJson<Void> deleteWechatMenu(Integer id) {
        weChatDao.deleteWechatMenu(id);
        return ResponseJson.success();
    }

    /**
     * 微信公众号菜单发布
     *
     * @param type 类型： 1采美，2呵呵商城
     */
    @Override
    public ResponseJson<Void> pushWechatMenu(Integer type) {
        String wxType = "";
        if (null != type && 1 == type) {
            wxType = caimeiId;
        } else if (null != type && 2 == type) {
            wxType = heheId;
        } else {
            return ResponseJson.error("菜单类型不正确！", null);
        }
        // 一级菜单
        List<WechatMenu> rootMenus = weChatDao.getWechatMenuList(type, wxType);
        if (rootMenus.size() > 3) {
            return ResponseJson.error("最多包括3个一级菜单！", null);
        }
        // 组装请求数据
        JSONArray jsonArr = new JSONArray();
        for (WechatMenu menu : rootMenus) {
            JSONObject button = new JSONObject();
            button.put("name", menu.getName());
            if (StringUtils.hasLength(menu.getType())) {
                // type不为空，则只有一级菜单
                setMenuJsonValue(button, menu);
            } else {
                // type 为空，则有二级菜单
                List<WechatMenu> subList = weChatDao.getWechatMenuList(menu.getId(), wxType);
                if (subList.size() > 5) {
                    return ResponseJson.error("每个一级菜单最多包含5个二级菜单！", null);
                }
                JSONArray subArr = new JSONArray();
                for (WechatMenu sub : subList) {
                    JSONObject subBtn = new JSONObject();
                    subBtn.put("name", sub.getName());
                    setMenuJsonValue(subBtn, sub);
                    subArr.add(subBtn);
                }
                // 把二级菜单放入上级菜单中
                button.put("sub_button", subArr);
            }
            jsonArr.add(button);
        }
        JSONObject json = new JSONObject();
        json.put("button", jsonArr);
        // json 字符串
        String jsonString = json.toJSONString();
        log.info(">>>>>>>>微信公众号菜单发布,发布数据：" + jsonString);
        // 组装请求链接
        String url = wechatApiUrl + "/cgi-bin/menu/create?access_token=";
        if (1 == type) {
            // 采美微信公众号
            url += getAccessToken(caimeiAppid, caimeiSecret);
        } else if (2 == type) {
            // 呵呵商城公众号
            url += getAccessToken(heheAppid, heheSecret);
        }
        // 得到结果String
        String jsonResult = null;
        try {
            jsonResult = HttpUtil.httpRequest(url, "POST", jsonString);
        } catch (Exception e) {
            log.error("发布微信公众号菜单失败：", e);
            return ResponseJson.error("微信接口请求失败，请联系管理员！", null);
        }
        if(StringUtils.hasLength(jsonResult)){
            JSONObject jsonObject = JSON.parseObject(jsonResult);
            if("0".equals(jsonObject.getString("errcode"))){
                return ResponseJson.success("发布成功！", null);
            }else{
                log.info(jsonResult);
                return ResponseJson.error(jsonObject.getString("errmsg"), null);
            }
        } else {
            return ResponseJson.error("发布失败，请联系管理员！", null);
        }
    }

    /**
     * 组装菜单数据
     */
    private void setMenuJsonValue(JSONObject json, WechatMenu menu) {
        json.put("type", menu.getType());
        if ("view".equals(menu.getType())) {
            json.put("url", menu.getUrl());
        } else if ("miniprogram".equals(menu.getType())) {
            // 小程序跳转
            json.put("url", publicUrl);
            json.put("appid", menu.getAppid());
            json.put("pagepath", menu.getPagePath());
        } else if ("article_id".equals(menu.getType()) || "article_view_limited".equals(menu.getType())) {
            json.put("article_id", menu.getArticleId());
        } else if ("media_id".equals(menu.getType()) || "view_limited".equals(menu.getType())) {
            json.put("media_id", menu.getMediaId());
        } else {
            json.put("key", menu.getKey());
            if(!"click".equals(menu.getType())) {
                json.put("sub_button", new ArrayList());
            }
        }
    }

    /**
     * 换取 access_token
     */
    public String getAccessToken(String appid, String secret){
        String url = wechatApiUrl + "/cgi-bin/token?grant_type=client_credential&appid=" + appid + "&secret=" + secret;
        try {
            String jsonResult = HttpUtil.httpRequest(url, "GET", null);
            if(StringUtils.hasLength(jsonResult)){
                JSONObject jsonObject = JSON.parseObject(jsonResult);
                String accessToken = jsonObject.getString("access_token");
                if(StringUtils.hasLength(accessToken)){
                    return	accessToken;
                }else{
                    log.info(jsonResult);
                }
            }
        } catch (Exception ignored) {}
        return "";
    }
}
