package com.caimei365.manager.service.wechat.impl;

import com.caimei365.manager.dao.SystemDao;
import com.caimei365.manager.dao.WeChatDao;
import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.wechat.WechatText;
import com.caimei365.manager.service.wechat.WechatTextService;
import com.github.pagehelper.PageHelper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/1/6
 */
@Slf4j
@Service
public class WechatTextServiceImpl implements WechatTextService {

    @Value("${wechat.caimei.id}")
    private String caimeiId;
    @Value("${wechat.hehe.id}")
    private String heheId;

    @Resource
    private WeChatDao weChatDao;
    @Resource
    private SystemDao systemDao;

    /**
     * 获取文本素材列表
     *
     * @param type     类型： 1采美，2呵呵商城
     * @param title    标题
     * @param pageNum  页码
     * @param pageSize 每页大小
     */
    @Override
    public ResponseJson<PaginationVo<WechatText>> getTextList(Integer type, String title, int pageNum, int pageSize) {
        String wxType = "";
        if (null != type && 1 == type) {
            wxType = caimeiId;
        } else if (null != type && 2 == type) {
            wxType = heheId;
        }
        PageHelper.startPage(pageNum, pageSize);
        List<WechatText> textList = weChatDao.getTextList(wxType, title);
        PaginationVo<WechatText> pageData = new PaginationVo<>(textList);
        return ResponseJson.success(pageData);
    }

    /**
     * 根据ID获取文本素材
     *
     * @param id
     */
    @Override
    public ResponseJson<WechatText> getText(Integer id) {
        WechatText text = weChatDao.getWechatText(id);
        return ResponseJson.success(text);
    }

    /**
     * 根据ID更新文本素材
     */
    @Override
    public ResponseJson<Void> updateText(Integer id, WechatText text, String username) {
        WechatText dbText = weChatDao.getWechatText(id);
        if (null == dbText) {
            return ResponseJson.error("当前回复配置异常！", null);
        }
        if (StringUtils.hasLength(text.getTitle())){
            dbText.setTitle(text.getTitle());
        }
        if (StringUtils.hasLength(text.getContent())){
            dbText.setContent(text.getContent());
        }
        if (null != text.getType() && 1 == text.getType()) {
            dbText.setWxType(caimeiId);
        } else if (null != text.getType() && 2 == text.getType()) {
            dbText.setWxType(heheId);
        }
        Integer userId = systemDao.getUserIdByUsername(username);
        dbText.setUserId(userId);
        // 更新
        weChatDao.updateWechatText(dbText);
        return ResponseJson.success();
    }

    /**
     * 添加文本素材
     */
    @Override
    public ResponseJson<Void> addText(WechatText text, String username) {
        if (null != text.getType() && 1 == text.getType()) {
            text.setWxType(caimeiId);
        } else if (null != text.getType() && 2 == text.getType()) {
            text.setWxType(heheId);
        } else {
            return ResponseJson.error("配置类型type不正确！", null);
        }
        Integer userId = systemDao.getUserIdByUsername(username);
        text.setUserId(userId);
        // 新增
        weChatDao.insertWechatText(text);
        return ResponseJson.success();
    }

    /**
     * 根据ID删除文本素材
     */
    @Override
    public ResponseJson<Void> deleteText(Integer id) {
        weChatDao.deleteWechatText(id);
        return ResponseJson.success();
    }
}
